@@ -12,11 +12,11 @@ from collections import namedtuple
 import time
 import warnings
 
-from blist import sortedlist
+from sortedcontainers import SortedList, SortedListWithKey
 
 
 __all__ = ['Gauge', 'Momentum']
-__version__ = '0.0.8'
+__version__ = '0.0.9'
 
 
 add = 1
@@ -28,10 +28,6 @@ def now_or(at):
     return time.time() if at is None else float(at)
 
 
-def indexer(x):
-    return lambda v: v[x]
-
-
 class Gauge(object):
     """Represents a gauge. A gauge has a value at any moment. It can be
     modified by an user's adjustment or an effective momentum.
@@ -51,8 +47,8 @@ class Gauge(object):
         self._min = min
         self.value = value
         self.set_at = now_or(at)
-        self.momenta = sortedlist(key=indexer(2))
-        self._plan = sortedlist(key=indexer(0))
+        self.momenta = SortedListWithKey(key=lambda m: m[-1])  # sort by until
+        self._plan = SortedList()
 
     @property
     def determination(self):
@@ -313,8 +309,8 @@ class Gauge(object):
         :param at: the time base. (default: now)
         """
         at = now_or(at)
-        start = self.momenta.bisect_right(Momentum(0, until=None))
-        stop = self.momenta.bisect_left(Momentum(0, until=at))
+        start = self.momenta.bisect_left((at,))
+        stop = self.momenta.bisect_right((None,))
         return self._coerce_and_remove_momenta(value, at, start, stop)
 
     def determine(self):
@@ -323,7 +319,7 @@ class Gauge(object):
 
         :returns: a sorted list of the determination.
         """
-        determination = sortedlist(key=indexer(0))
+        determination = SortedList()
         # accumulated velocities and the sum of velocities
         velocities = []
         total_velocity = 0
